| Title: | Give Thanks |
|---|---|
| Description: | Give thanks to the people with the thank 📦. |
| Authors: | Jim Hester [aut, cre] (ORCID: <https://orcid.org/0000-0002-2739-7082>), RStudio [cph, fnd] |
| Maintainer: | Jim Hester <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-16 06:36:13 UTC |
| Source: | https://github.com/jimhester/thank |
Pick a random thank you gif and copy it to the clipboard
you()you()